/*
 * Copyright (c) 2014 Nicira, Inc.
 * Copyright (c) 2014 Cisco Systems, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef OPENVSWITCH_VERSION_H
#define OPENVSWITCH_VERSION_H 1

#define OVS_PACKAGE_STRING  "openvswitch 4.0.0"
#define OVS_PACKAGE_VERSION "4.0.0"

#define OVS_LIB_VERSION     0
#define OVS_LIB_REVISION    0
#define OVS_LIB_AGE         0

#endif /* openvswitch/version.h */
